@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
- * Copyright (C) 2011-2015  Kamil Ignacak (acerion@wp.pl)
+ * Copyright (C) 2011-2017  Kamil Ignacak (acerion@wp.pl)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -581,7 +581,7 @@ int main (int argc, char *const argv[])
 	}
 	config->is_cw = 1;
 
-	if (!cw_process_argv(argc, argv, all_options, config)) {
+	if (!cw_process_argv(combined_argc, combined_argv, all_options, config)) {
 		fprintf(stderr, _("%s: failed to parse command line args\n"), config->program_name);
 		return EXIT_FAILURE;
 	}
