@@ -3,16 +3,21 @@
   unixcw project is covered by GNU General Public License.
 */
 
-
 #ifndef H_LIBCW_NULL
 #define H_LIBCW_NULL
 
 
-#include "libcw_internal.h"
 
 
+
+#include "libcw_gen.h"
+#include "libcw_tq.h"
+
 int  cw_null_configure(cw_gen_t *gen, const char *device);
 void cw_null_write(cw_gen_t *gen, cw_tone_t *tone);
 
 
+
+
+
 #endif /* #ifndef H_LIBCW_NULL */
