@@ -242,7 +242,8 @@ unsigned int test_cw_tq_enqueue_internal_2(void);
 unsigned int test_cw_tq_is_full_internal(void);
 unsigned int test_cw_tq_test_capacity_1(void);
 unsigned int test_cw_tq_test_capacity_2(void);
-unsigned int test_cw_queue_tone(void);
+// unsigned int test_cw_queue_tone(void); /* No such function. */
+unsigned int test_cw_tq_wait_for_level_internal(void);
 
 #endif /* #ifdef LIBCW_UNIT_TESTS */
 
