@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
- * Copyright (C) 2011-2015  Kamil Ignacak (acerion@wp.pl)
+ * Copyright (C) 2011-2017  Kamil Ignacak (acerion@wp.pl)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -1305,12 +1305,12 @@ void test_straight_key(cw_test_stats_t *stats)
 
 		/* Alternate between open and closed. */
 		for (int i = 0; i < 5; i++) {
-			if (!cw_notify_straight_key_event(CW_KEY_STATE_OPEN)) {
+			if (CW_SUCCESS != cw_notify_straight_key_event(CW_KEY_STATE_OPEN)) {
 				event_failure = true;
 				break;
 			}
 
-			if (cw_get_straight_key_state()) {
+			if (CW_KEY_STATE_OPEN != cw_get_straight_key_state()) {
 				state_failure = true;
 				break;
 			}
@@ -1330,12 +1330,12 @@ void test_straight_key(cw_test_stats_t *stats)
 			cw_nanosleep_internal(&t);
 #endif
 
-			if (!cw_notify_straight_key_event(CW_KEY_STATE_CLOSED)) {
+			if (CW_SUCCESS != cw_notify_straight_key_event(CW_KEY_STATE_CLOSED)) {
 				event_failure = true;
 				break;
 			}
 
-			if (!cw_get_straight_key_state()) {
+			if (CW_KEY_STATE_CLOSED != cw_get_straight_key_state()) {
 				state_failure = true;
 				break;
 			}
@@ -1356,6 +1356,9 @@ void test_straight_key(cw_test_stats_t *stats)
 #endif
 		}
 
+		/* Whatever happens during tests, keep the key open after the tests. */
+		cw_notify_straight_key_event(CW_KEY_STATE_OPEN);
+
 		printf("\n");
 		fflush(stdout);
 
