@@ -1,5 +1,5 @@
 // Copyright (C) 2001-2006  Simon Baldwin (simon_baldwin@yahoo.com)
-// Copyright (C) 2011-2015  Kamil Ignacak (acerion@wp.pl)
+// Copyright (C) 2011-2017  Kamil Ignacak (acerion@wp.pl)
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -119,7 +119,7 @@ void Receiver::handle_key_event(QKeyEvent *event, bool is_reverse_paddles)
 			/* These keys are obvious candidates for
 			   "straight key" key. */
 
-			fprintf(stderr, "---------- handle key event: sk: %d\n", is_down);
+			//fprintf(stderr, "---------- handle key event: sk: %d\n", is_down);
 			sk_event(is_down);
 			event->accept();
 
@@ -165,7 +165,7 @@ void Receiver::handle_mouse_event(QMouseEvent *event, bool is_reverse_paddles)
 			|| event->type() == QEvent::MouseButtonDblClick;
 
 		if (event->button() == Qt::MidButton) {
-			fprintf(stderr, "---------- handle mouse event: sk: %d\n", is_down);
+			//fprintf(stderr, "---------- handle mouse event: sk: %d\n", is_down);
 			sk_event(is_down);
 			event->accept();
 
@@ -485,15 +485,9 @@ void Receiver::poll_character()
 
 		case ENOENT:
 			/* Invalid character in receiver's buffer. */
-			{	/* New scope to avoid gcc 3.2.2
-				   internal compiler error. */
-
-				cw_clear_receive_buffer();
-				textarea->append('?');
-
-				QString status = _("Unknown character received at %1 WPM");
-				app->show_status(status.arg(cw_get_receive_speed()));
-			}
+			cw_clear_receive_buffer();
+			textarea->append('?');
+			app->show_status(QString(_("Unknown character received at %1 WPM")).arg(cw_get_receive_speed()));
 			break;
 
 		default:
